@@ -67,7 +67,7 @@ module Debci
     include Debci::TestHandler
 
     register Sinatra::Namespace
-    set :views, File.dirname(__FILE__) + '/api'
+    set :views, "#{File.dirname(__FILE__)}/api"
 
     attr_reader :suite, :arch, :user
 
@@ -76,7 +76,7 @@ module Debci
     end
 
     get '/' do
-      redirect request.script_name + '/doc'
+      redirect "#{request.script_name}/doc"
     end
 
     namespace '/v1' do
@@ -153,7 +153,7 @@ module Debci
       * `:run_id`: which Job ID to retry
       EOF
       post '/retry/:run_id' do
-        if not @user
+        if !@user
           authenticate_key!
         end
         run_id = params[:run_id]
